==> moodle_1.3.1.orig.tar.gz: moodle/lang/ar/exercise.php <==
<?PHP // $Id: exercise.php,v 1.3 2004/02/03 09:12:31 moodler Exp $ 
      // exercise.php - created with Moodle 1.2 development (2004012800)


$string['absent'] = '';
$string['accumulative'] = '';
$string['action'] = '';
$string['ago'] = '$a  ';
$string['allgradeshaveamaximumof'] = '    : $a';
$string['amend'] = '';
$string['amendassessmentelements'] = '  ';
$string['amendtitle'] = ' ';
$string['assess'] = '';
$string['assessed'] = ' ';
$string['assessment'] = '';
$string['assessmentby'] = '  $a';
$string['assessmentform'] = ' ';
$string['assessmentmadebythe'] = '     $a';
$string['assessmentofthissubmission'] = '  ';
$string['assessments'] = '';
$string['atthisstageyou'] = '      .</ br>         <br />             .< />            .';
$string['awaitingassessmentbythe'] = '     $a';
$string['awaitingfeedbackfromthe'] = '     $a';
$string['clearlateflag'] = '  ';
$string['comment'] = '';
$string['confirmdeletionofthisitem'] = '    $a';
$string['correct'] = '';
$string['criterion'] = '';
$string['deadline'] = ' ';
$string['deadlineis'] = '    $a';
$string['delete'] = '';
$string['deleting'] = '';
$string['description'] = '';
$string['descriptionofexercise'] = '         $a    (Word)   (HTML).          $a .            ,  (Word)   (HTML),             $a .';
$string['detailsofassessment'] = ' ';
$string['displayoffinalgrades'] = '  ';
$string['doubleupload'] = ' :        .    ,           .     .';
$string['duedate'] = ' ';
$string['edit'] = '';
$string['editingassessmentelements'] = '  ';
$string['element'] = '';
$string['elementweight'] = ' ';
$string['entriessaved'] = '  ';
$string['errorbanded'] = ' ';
$string['excellent'] = '';
$string['exerciseassessments'] = ' ';
$string['exercisefeedback'] = '  ';
$string['exercisesubmissions'] = ' ';
$string['generalcomment'] = ' ';
$string['good'] = '';
$string['gradeassessment'] = ' ';
$string['gradeforassessment'] = ' ';
$string['gradeforstudentsassessment'] = '   $a ';
$string['gradeforsubmission'] = ' ';
$string['gradetable'] = ' ';
$string['gradingstrategy'] = '  ';
$string['handlingofmultiplesubmissions'] = '  ';
$string['hidenamesfromstudents'] = '  ';
$string['incorrect'] = ' ';
$string['leaguetable'] = '     ';
$string['mail1'] = '   \'$a\' ';
$string['mail2'] = '       \'$a\'';
$string['mail3'] = '    ';
$string['mail6'] = '    \'$a\' ';
$string['mail7'] = '   $a    ';
$string['managingassignment'] = ' ';
$string['maximumsize'] = ' ';
$string['modulename'] = '';
$string['modulenameplural'] = '';
$string['movingtophase'] = '    $a';
$string['multiplesubmissions'] = ' ';
$string['noexercisedescriptionssubmitted'] = '    ';
$string['nosubmissions'] = '  ';
$string['notassessedyet'] = '  ';
$string['notavailable'] = ' ';
$string['noteonassessmentelements'] = '         .<br />

        .      .<br />

     .   .<br />

     ,        .<br />

  .         , .<br />

     &quot; &quot

';
$string['noteonstudentassessments'] = '{   /   }';
$string['notgraded'] = '    ';
$string['notitlegiven'] = '  ';
$string['nowpleasemakeyourownassessment'] = '        $a   

<br />         <br />   .          <br />        .

';
$string['numberofassessmentelements'] = ' ,  ,  ,      ';
$string['numberofentries'] = ' ';
$string['numberofnegativeresponses'] = '  ';
$string['onesubmission'] = ' ';
$string['optionaladjustment'] = ' ';
$string['overallgrade'] = ' ';
$string['phase'] = '';
$string['phase1'] = ' ';
$string['phase1short'] = '';
$string['phase2'] = '  $a  ';
$string['phase2short'] = '';
$string['phase3'] = ' $a  ';
$string['phase3short'] = '';
$string['pleasegradetheassessment'] = '      $a';
$string['pleasesubmityourwork'] = '     ';
$string['pleaseusethisform'] = '     <br />       .';
$string['pleaseviewtheexercise'] = '          . .<br />        . .<br />     .<br />       (    ) .<br />       .       <br />      .';
$string['poor'] = '';
$string['present'] = '';
$string['reasonforadjustment'] = ' ';
$string['reassess'] = ' ';
$string['resubmissionfor'] = '   $a';
$string['resubmitnote'] = '*      $a    . <br />            <br />  <b>  $a    </ b>  . <br />         <b></ b>   .';
$string['rubric'] = '';
$string['savedok'] = '  ';
$string['saveentries'] = ' ';
$string['savemyassessment'] = ' ';
$string['saveweights'] = ' ';
$string['scale10'] = '  10';
$string['scale100'] = '  100';
$string['scale20'] = '  20';
$string['scalecorrect'] = '2   /   ';
$string['scaleexcellent4'] = '4  /   ';
$string['scaleexcellent5'] = '5  /   ';
$string['scaleexcellent7'] = '7  /   ';
$string['scalegood3'] = '3   / ';
$string['scalepresent'] = '2   /  ';
$string['scaleyes'] = '2   /   ';
$string['specimenassessmentform'] = '  ';
$string['studentallowedtoresubmit'] = '$a    ';
$string['studentassessments'] = '$a ';
$string['studentnotallowed'] = '$a     ';
$string['studentsubmissions'] = '$a ';
$string['studentsubmissionsforassessment'] = ' $a   ';
$string['submission'] = '';
$string['submissions'] = '';
$string['submissionsnowclosed'] = '   -    ';
$string['submitexercisedescription'] = '  ';
$string['submitted'] = ' ';
$string['submittedby'] = '  ';
$string['suggestedgrade'] = ' ';
$string['teacherassessment'] = ' $a ';
$string['teacherassessmenttable'] = ' $a   ';
$string['teacherscomment'] = ' ';
$string['theexercise'] = '';
$string['theexerciseandthesubmissionby'] = ' $a   ';
$string['thegradeis'] = ' $a  ';
$string['thereisfeedbackfromthe'] = ' $a   ';
$string['thisisaresubmission'] = '    a . 

<br />      $ . <br />     ,      <br />         .';
$string['title'] = '';
$string['typeofscale'] = ' ';
$string['ungradedstudentassessments'] = ' $a      ';
$string['usemaximum'] = ' ';
$string['usemean'] = ' ';
$string['verypoor'] = ' ';
$string['view'] = '';
$string['viewassessment'] = ' ';
$string['warningonamendingelements'] = ':      . <br />     ѡ  ӡ   .';
$string['weightederrorcount'] = '  : $a';
$string['weightforgradingofassessments'] = '  ';
$string['weightforteacherassessments'] = '   $a ';
$string['weights'] = '';
$string['weightssaved'] = '  ';
$string['weightsusedforoverallgrade'] = '   ';
$string['yourassessment'] = '';
$string['yourfeedbackgoeshere'] = '  ';
$string['yoursubmission'] = '';

?>

==> moodle_1.4.3.orig.tar.gz: moodle/lang/ar/exercise.php <==
<?PHP // $Id$ 
      // exercise.php - created with Moodle 1.4 development (2004081200)


$string['absent'] = '';
$string['accumulative'] = '';
$string['action'] = '';
$string['ago'] = '$a  ';
$string['amend'] = '';
$string['amendassessmentelements'] = '  ';
$string['amendtitle'] = ' ';
$string['analysis'] = '';
$string['assess'] = '';
$string['assessed'] = ' ';
$string['assessment'] = '';
$string['assessmentby'] = '  $a';
$string['assessmentform'] = ' ';
$string['assessmentmadebythe'] = '     $a';
$string['assessmentofthissubmission'] = '  ';
$string['assessments'] = '';
$string['atthisstageyou'] = '      .</ br>         <br />             .< />            .';
$string['awaitingassessmentbythe'] = '     $a';
$string['clearlateflag'] = '  ';
$string['comment'] = '';
$string['comparisonofassessments'] = ' ';
$string['confirmdeletionofthisitem'] = '    $a';
$string['correct'] = '';
$string['count'] = '';
$string['criterion'] = '';
$string['deadline'] = ' ';
$string['deadlineis'] = '    $a';
$string['delete'] = '';
$string['deleting'] = '';
$string['description'] = '';
$string['descriptionofexercise'] = '         $a    (Word)   (HTML).          $a .            ,  (Word)   (HTML),             $a .';
$string['detailsofassessment'] = ' ';
$string['displayoffinalgrades'] = '  ';
$string['doubleupload'] = ' :        .    ,           .     .';
$string['duedate'] = ' ';
$string['edit'] = '';
$string['editingassessmentelements'] = '  ';
$string['element'] = '';
$string['elementweight'] = ' ';
$string['entriessaved'] = '  ';
$string['errorbanded'] = ' ';
$string['excellent'] = '';
$string['exerciseassessments'] = ' ';
$string['exercisefeedback'] = '  ';
$string['exercisesubmissions'] = ' ';
$string['fair'] = '';
$string['generalcomment'] = ' ';
$string['good'] = '';
$string['gradeassessment'] = ' ';
$string['gradeforassessment'] = ' ';
$string['gradeforstudentsassessment'] = '   $a ';
$string['gradeforsubmission'] = ' ';
$string['gradetable'] = ' ';
$string['gradinggrade'] = ' ';
$string['gradingstrategy'] = '  ';
$string['handlingofmultiplesubmissions'] = '  ';
$string['hidenamesfromstudents'] = '  ';
$string['incorrect'] = ' ';
$string['late'] = '';
$string['leaguetable'] = '     ';
$string['mail1'] = '   \'$a\' ';
$string['mail2'] = '       \'$a\'';
$string['mail3'] = '    ';
$string['mail6'] = '    \'$a\' ';
$string['mail7'] = '   $a    ';
$string['managingassignment'] = ' ';
$string['maximumgradeforstudentassessments'] = '   : $a';
$string['maximumgradeforsubmissions'] = '  : $a';
$string['maximumsize'] = ' ';
$string['modulename'] = '';
$string['modulenameplural'] = '';
$string['movingtophase'] = '    $a';
$string['multiplesubmissions'] = ' ';
$string['noexercisedescriptionssubmitted'] = '    ';
$string['nosubmissions'] = '  ';
$string['notassessedyet'] = '  ';
$string['notavailable'] = ' ';
$string['noteonassessmentelements'] = '         .<br />
        .      .<br />
     .   .<br />
     ,        .<br />
  .         , .<br />
     \" \"';
$string['noteonstudentassessments'] = '{   /   }';
$string['notgraded'] = '    ';
$string['notitlegiven'] = '  ';
$string['numberofassessmentelements'] = ' ,  ,  ,      ';
$string['numberofentries'] = ' ';
$string['numberofnegativeresponses'] = '  ';
$string['onesubmission'] = ' ';
$string['optionaladjustment'] = ' ';
$string['overallgrade'] = ' ';
$string['phase'] = '';
$string['phase1'] = ' ';
$string['phase1short'] = '';
$string['phase2'] = '  $a  ';
$string['phase2short'] = '';
$string['phase3'] = ' $a  ';
$string['phase3short'] = '';
$string['pleasegradetheassessment'] = '      $a';
$string['pleasesubmityourwork'] = '     ';
$string['pleaseusethisform'] = '     <br />       .';
$string['pleaseviewtheexercise'] = '          . .<br />        . .<br />     .<br />       (    ) .<br />       .       <br />      .';
$string['poor'] = '';
$string['present'] = '';
$string['reasonforadjustment'] = ' ';
$string['reassess'] = ' ';
$string['resubmissionfor'] = '   $a';
$string['resubmitnote'] = '*      $a    . <br />            <br />  <b>  $a    </ b>  . <br />         <b></ b>   .';
$string['rubric'] = '';
$string['savedok'] = '  ';
$string['saveentries'] = ' ';
$string['savemyassessment'] = ' ';
$string['saveweights'] = ' ';
$string['scale10'] = '  10';
$string['scale100'] = '  100';
$string['scale20'] = '  20';
$string['scalecorrect'] = '2   /   ';
$string['scaleexcellent4'] = '4  /   ';
$string['scaleexcellent5'] = '5  /   ';
$string['scaleexcellent7'] = '7  /   ';
$string['scalegood3'] = '3   / ';
$string['scalepresent'] = '2   /  ';
$string['scaleyes'] = '2   /   ';
$string['specimenassessmentform'] = '  ';
$string['studentallowedtoresubmit'] = '$a    ';
$string['studentassessments'] = '$a ';
$string['studentnotallowed'] = '$a     ';
$string['studentsubmissions'] = '$a ';
$string['studentsubmissionsforassessment'] = ' $a   ';
$string['submission'] = '';
$string['submissions'] = '';
$string['submissionsnowclosed'] = '   -    ';
$string['submitexercisedescription'] = '  ';
$string['submitted'] = ' ';
$string['submittedby'] = '  ';
$string['suggestedgrade'] = ' ';
$string['teacherassessment'] = ' $a ';
$string['teacherassessmenttable'] = ' $a   ';
$string['teacherscomment'] = ' ';
$string['theexercise'] = '';
$string['theexerciseandthesubmissionby'] = ' $a   ';
$string['thegradeis'] = ' $a  ';
$string['thereisfeedbackfromthe'] = ' $a   ';
$string['thisisaresubmission'] = '    a . 
<br />      $ . <br />     ,      <br />         .';
$string['title'] = '';
$string['typeofscale'] = ' ';
$string['ungradedstudentassessments'] = ' $a      ';
$string['usemaximum'] = ' ';
$string['usemean'] = ' ';
$string['verypoor'] = ' ';
$string['view'] = '';
$string['warningonamendingelements'] = ':      . <br />     ѡ  ӡ   .';
$string['weightederrorcount'] = '  : $a';
$string['weightforgradingofassessments'] = '  ';
$string['weightforteacherassessments'] = '   $a ';
$string['weights'] = '';
$string['weightssaved'] = '  ';
$string['weightsusedforoverallgrade'] = '   ';
$string['yourassessment'] = '';
$string['yourfeedbackgoeshere'] = '  ';
$string['yoursubmission'] = '';

?>
